/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef UCQTABLETOOLBAR_H_
#define UCQTABLETOOLBAR_H_
#include <QToolBar>
#include <QAction>
#include <QComboBox>

/**
 * \class UCQTableToolBar
 * \brief Toolbar for table operations.
 *
 * This toolbar allows to resize the cells of the UCQTableView, to open the
 * UCQSearchDialog, to clear the table, cut and crop selections and to create
 * new blocks in the TableModel.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see MainWindow
 */
class UCQTableToolBar: public QToolBar
{

Q_OBJECT

public:
    UCQTableToolBar  ( QWidget* );

    void enableActions        ( bool );
    void enableAddBlockAction ( bool );

private:
    /**
     * \brief Zoom in action.
     */
    QAction* zoomInAction_;
    /**
     * \brief Zoom out action.
     */
    QAction* zoomOutAction_;
    /**
     * \brief SearchDialog action.
     */
    QAction* searchAction_;
    /**
     * \brief BlockDialog action.
     */
    QAction* addBlockAction_;
    /**
     * \brief Clear visible table action.
     */
    QAction* clearAction_;
    /**
     * \brief Cut selection action.
     */
    QAction* cutSelectionAction_;
    /**
     * \brief Crop selection action, i.e. reduce visible table on selected
     *        items.
     */
    QAction* cropSelectionAction_;

    QComboBox * sortCombo_;

signals:
    /**
     * \brief Emitted when zoom in is pressed.
     */
    void zoomInPressed ();
    /**
     * \brief Emitted when zoom out is pressed.
     */
    void zoomOutPressed ();
    /**
     * \brief Emitted when search is pressed.
     */
    void searchPressed ();
    /**
     * \brief Emitted when add block is pressed.
     */
    void addBlockPressed ();
    /**
     * \brief Emitted when clear is pressed.
     */
    void clearPressed ();
    /**
     * \brief Emitted when cut selection is pressed.
     */
    void cutSelectionPressed ();
    /**
     * \brief Emitted when crop selection is pressed.
     */
    void cropSelectionPressed ();
};

#endif /* TABLETOOLBAR_H_ */
